# Changelog

<!--next-version-placeholder-->

## v0.0.3 (2021-09-30)
### Fix
* Fix copy and paste error in setup.py. ([`bf6c32b`](https://github.com/andrewjw/prom433/commit/bf6c32b297e2b1a4323caca06dd937a6b59752f0))

## v0.0.2 (2021-09-30)
### Fix
* Set semantic release to release from main. ([`04af98b`](https://github.com/andrewjw/prom433/commit/04af98b0c9b5a39bd4dd87ac5a2003a098894df8))
* Default branch is called main, not master. ([`d5bf17a`](https://github.com/andrewjw/prom433/commit/d5bf17a3aaeb97e8c0051602630433b936bc7736))
* Make the tests pass. ([`5ecfb35`](https://github.com/andrewjw/prom433/commit/5ecfb35721e6d0df1656dfb7feac25798656b7d0))
